@@ -1,9 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-from PyQt4.QtNetwork import QNetworkRequest
-import HTMLParser,  re
+from PyQt4.QtNetwork import QNetworkRequest, QNetworkReply
+import HTMLParser, re, os
 from urlparse import urlparse
+import urllib2, time
 from utils.htmlTools import htmlTools
 from utils.DebugLog import DebugLog
 from Extractor import Extractor
@@ -56,6 +57,13 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
       elif self.tagHeureMission and tag == 'a':
          self.tagTrainA = True
 
+         if dict(attrs)['href']:
+            url = dict(attrs)['href']
+            url = 'http://wap.ratp.fr/siv/'+re.sub(';jsessionid=.+?\?', '?', url)+"&exid=%f"%(1000*time.clock())
+            DebugLog(url)
+            self.currentRide.detailsUrl = url
+            self.parseDetails = True
+
    def handle_data(self, data):
       if self.tagDestination:
          u = data.replace('>', '').strip()
@@ -85,14 +93,15 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          DebugLog(data.strip())
 
    def handle_endtag(self, tag):
-      if self.tagHeurePassageB and tag=='b':
-         self.tagHeurePassage = False
-         self.tagHeurePassageB = False
-         self.listRides.append(self.currentRide)
-         self.currentRide = None
+      if self.tagHeurePassageB and tag=='b' or self.tagError:
+         if not self.tagError:
+            self.tagHeurePassage = False
+            self.tagHeurePassageB = False
 
-      if self.tagError:
-         self.listRides.append(self.currentRide)
+         if self.currentRide.heure==u'sans arrêt':
+            DebugLog("sans arret")
+         else:
+            self.listRides.append(self.currentRide)
          self.currentRide = None
 
       self.tagDestination ^= (self.tagDestination and tag=='div')
@@ -106,7 +115,61 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          self.rideModel.SetInfo('ERROR', 'Sens du trajet indéfini: "%s"'%self.sens)
 
       self.AppendRidesToModel(imax)
-      return self.perturbation, self.error
+
+   def MatchTrains(self, data, ride):
+      DebugLog("Extractor::MatchTrains %s"%ride.train)
+
+      ride.match=False
+
+      stops = re.findall("missionstation-on.+?>(.+?)<", str(data))
+          
+      s = str(self.depart)
+      s = re.sub("([âaàä])",  "a", s)
+      s = re.sub("([éèêeë])", "e", s)
+      s = re.sub("([iîï])",   "i", s)
+      s = re.sub("([uüûù])",  "u", s)
+      s = re.sub("([oôö])",   "o", s)
+      s = re.sub("([\-\s'])", " ", s)
+
+      if s in stops:
+         DebugLog('   quick MATCH D %s'%s)
+         ride.match=True
+      else:
+         DebugLog('   NO quick match D %s'%s)
+         for stop in stops:
+            if re.search(s, stop) or re.search(stop, s):
+               DebugLog('match %s %s Dreturn'%(s,stop))
+               ride.match=True
+               break
+
+         if not ride.match:
+            DebugLog("   NO match D %s, return"%s)
+            return
+            
+      s = str(self.arrivee)
+      s = re.sub("([âaàä])",  "a", s)
+      s = re.sub("([éèêeë])", "e", s)
+      s = re.sub("([iîï])",   "i", s)
+      s = re.sub("([uüûù])",  "u", s)
+      s = re.sub("([oôö])",   "o", s)
+      s = re.sub("([\-\s'])", " ", s)
+
+      ride.match=False
+      if ride in stops:
+         DebugLog('   quick MATCH A %s'%s)
+         ride.match=True
+      else:
+         DebugLog('   NO quick match %s'%s)
+
+         for stop in stops:
+            if re.search(s, stop) or re.search(stop, s):
+               ride.match=True
+               DebugLog('   MATCH A %s %s'%(s,stop))
+               break
+
+         if not ride.match:
+            DebugLog("   NO match A %s, return"%s)
+            return
 
    def ParsePerturbation(self, str):
       DebugLog("TableParserTransilien::ParsePerturbation")
@@ -117,7 +180,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          for p in res:
             s = 'alt="\s%s".+?<b>.+?</b>(.+?)(?:<img.+?alt="RER")'%self.ligne
             r = re.search(s, p, re.DOTALL)
-            
+
             if not r:
                s = 'alt="\s%s".+?<b>.+?</b>(.+?)(?:<b>Trafic normal)'%self.ligne
                r = re.search(s, p, re.DOTALL)
@@ -131,7 +194,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
             p=p.replace('\n',' ').replace('<br>', '\n')
             p=re.sub('\s+', ' ', p)
             p = re.sub('<.+?>', '', p).strip().replace('&#39;', "'")
-            
+
             self.rideModel.AddPerturbation( unicode(p, 'utf-8') )
 
 class ExtractorRERratp(TableParserRERratp):
@@ -141,6 +204,7 @@ class ExtractorRERratp(TableParserRERratp):
       Extractor.__init__(self, ligne.id)
 
       self.depart = ligne.depart
+      self.arrivee = ligne.arrivee
       self.station = ligne.codeDepart
       self.ligne = ligne.ligne
       self.sens = ligne.direction
