@@ -4,18 +4,22 @@
 from utils.DebugLog import DebugLog
 from PyQt4 import QtCore
 
-class Ride:
+class Ride(QtCore.QObject):
    def __init__(self):
+      QtCore.QObject.__init__(self)
+
       self.train = ''
       self.heure = ''
       self.destination = ''
       self.voie = ''
       self.error = ''
       self.noTrain = False
+      self.match = True
+      self.detailsUrl=''
 
    def setNoTrain(self, b):
       self.noTrain = b
-      
+
    def setTrain(self, train):
       self.train = train
 
@@ -34,6 +38,9 @@ class Ride:
    def __str__(self):
       return unicode('Train: %s, Heure: %s, Destination: %s, Voie: %s'%(self.train, self.heure, self.destination, self.voie))
 
+   def SendMatch(self, reply):
+      self.emit(QtCore.SIGNAL('match'), reply, self)
+
 class RideModel(QtCore.QObject):
    def __init__(self, id):
       DebugLog("RideModel::__init__")
@@ -51,7 +58,7 @@ class RideModel(QtCore.QObject):
       for ride in self.getRides():
          s += unicode(ride)+u'\n'
       return s
-      
+
    def Clear(self):
       DebugLog("RideModel::Clear")
       self.rides = []
@@ -66,7 +73,7 @@ class RideModel(QtCore.QObject):
          url = "http://fr.wikipedia.org/wiki/Ligne_%s_du_RER_d'Ile-de-France"%l
 
       return QtCore.QUrl(url)
-      
+
    def getIcon(self):
       return self.icon
 
