@@ -61,7 +61,7 @@ class TrainTrainModel(QAbstractTableModel):
    def SetOnline(self, b):
       self.online = b
 
-   def CreateAndAddRide(self, ligne):
+   def CreateAndAddRide(self, ligne, save=True):
       extractor = None
       if ligne.tec=='RER' and ligne.exploitant=='S':
          extractor = ExtractorTransilien(ligne)
@@ -74,7 +74,8 @@ class TrainTrainModel(QAbstractTableModel):
 
       if extractor:
          self.rideList[extractor.id] = extractor
-         self.AddRideModel( extractor.rideModel )
+         if save:
+            self.AddRideModel( extractor.rideModel )
          self.connect(extractor, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
          extractor.SetOnline(self.online)
          extractor.FetchDatas(self, self.max)
