@@ -16,7 +16,7 @@ class ConfFile:
       except:
          return ''
 
-class Ride:
+class RideConf:
    def __init__(self, ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction):
       self.ligne = ligne
       self.tec = tec
@@ -76,7 +76,7 @@ class RidesConfig:
          direction = t.get(section, 'direction')
 
          if codeDepart and codeArrivee and tec and depart and arrivee:
-            l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction)
+            l = RideConf(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction)
             self.AddRide(l, section)
 
       self.hasChanged = False
