@@ -3,7 +3,7 @@
 
 import os, sys, sqlite3, re
 from utils.DebugLog import DebugLog, getScriptPath
-from utils.Config import RidesConfig, ConfFile, Ride
+from utils.Config import RidesConfig, ConfFile, RideConf
 from utils.TrainDb import DbTrain
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import Qt
@@ -104,7 +104,7 @@ class SelectLine(QtGui.QDialog):
 
 class AddRideDlg(QtGui.QDialog):
 
-   def __init__(self, garesConf):
+   def __init__(self, garesConf=None):
       QtGui.QDialog.__init__(self)
 
       self.setWindowTitle(u'Ajouter un trajet')
@@ -204,10 +204,12 @@ class AddRideDlg(QtGui.QDialog):
       self.setLayout(vbox)
 
    def ReadConfig(self):
-      self.garesConf.ReadRides()
+      if self.garesConf:
+         self.garesConf.ReadRides()
 
    def WriteConfig(self):
-      self.garesConf.WriteRides()
+      if self.garesConf:
+         self.garesConf.WriteRides()
 
    def IsRATPcode(self, val):
       try:
@@ -331,8 +333,9 @@ class AddRideDlg(QtGui.QDialog):
 
       DebugLog('posD=%d, posA=%d, dir=%s'%(posDepart, posArrivee, direction))
 
-      l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitantD, direction)
-      self.garesConf.AddRide(l)
+      l = RideConf(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitantD, direction)
+      if self.garesConf:
+         self.garesConf.AddRide(l)
       return l
 
    def OnOK(self):
