@@ -47,7 +47,7 @@ class TrainTrainView(QtGui.QMainWindow):
 
    def IconPath(self, str):
       return os.path.join(self.iconsPath, str)
-      
+
    def ReInit(self):
       DebugLog("TrainTrainView::ReInit")
 
@@ -72,6 +72,21 @@ class TrainTrainView(QtGui.QMainWindow):
          rideModel = self.model.CreateAndAddRide(ride)
          self.AppendRideView(rideModel)
 
+   def AddRideSimple(self):
+      dlg = AddRideDlg()
+      dlg.exec_()
+      ride = dlg.added
+      if ride:
+         ride.id='simple'
+         rideModel = self.model.CreateAndAddRide(ride, False)
+         self.SetRideViewSimple(rideModel)
+
+   def SetRideViewSimple(self, rideModel):
+      view = RideView(rideModel, self)
+      self.views[rideModel.id] = view
+      self.vLayoutU.addWidget( view )
+      view.Busy()
+
    def AppendRideView(self, rideModel):
       view = RideView(rideModel, self)
       self.views[rideModel.id] = view
@@ -122,13 +137,6 @@ class TrainTrainView(QtGui.QMainWindow):
       file.addAction(settings)
       file.addAction(about)
 
-      self.scrollArea = QtGui.QScrollArea(self)#.centralWidget)
-      self.scrollArea.setWidgetResizable(True)
-
-      self.scrollAreaWidgetContents = QtGui.QWidget(self.scrollArea)
-      self.scrollArea.setWidget(self.scrollAreaWidgetContents)
-      self.scrollAreaWidgetContents.setObjectName('scroll')
-
       self.vLayout = QtGui.QVBoxLayout()
       self.vLayout.setSpacing(0)
       self.vLayout.setMargin(0)
@@ -140,37 +148,83 @@ class TrainTrainView(QtGui.QMainWindow):
       self.tLayout.addLayout(self.vLayout)
       addButton = QtGui.QPushButton('Ajouter un trajet')
       addButton.clicked.connect(self.AddRide)
-
-      self.tLayout.addWidget(addButton)
 #      addButton.setStyleSheet('background-color:#2684DB; color: #fff; ')
 
-      self.scrollAreaWidgetContents.setLayout( self.tLayout )
-      self.scrollAreaWidgetContents.setStyleSheet("QWidget#scroll { background: #fff; margin: 0; padding: 0;} ")
+      self.tLayout.addWidget(addButton)
+      self.scrollArea = self.CreateScrollWidget(self.tLayout)
 
-#      self.tabW = QtGui.QTabWidget()
-#      self.tabW.setTabPosition(QtGui.QTabWidget.East)
-#      self.tabW.addTab(self.scrollArea, 'Mes Trains')
-#      self.tabW.addTab(addButton, 'Horaire')
+      self.vLayoutU = QtGui.QVBoxLayout()
+      self.vLayoutU.setSpacing(0)
+      self.vLayoutU.setMargin(0)
+      self.vLayoutU.setAlignment(Qt.AlignTop)
 
-#      self.setCentralWidget(self.tabW)
-      self.setCentralWidget(self.scrollArea)
+      addButtonU = QtGui.QPushButton('Voir un trajet simple')
+      addButtonU.clicked.connect(self.AddRideSimple)
+      self.vLayoutU.addWidget(addButtonU)
+
+      self.scrollAreaU = self.CreateScrollWidget(self.vLayoutU)
+
+      self.tabW = QtGui.QTabWidget()
+      self.tabW.setTabPosition(QtGui.QTabWidget.East)
+
+      rotate = QtGui.QTransform().rotate(-90)
+      self.iconFav = QtGui.QIcon( QtGui.QPixmap(self.IconPath('mestrainsfav.png')).transformed(rotate) )
+      self.iconSim = QtGui.QIcon( QtGui.QPixmap(self.IconPath('mestrains.png')).transformed(rotate) )
+
+      self.tabW.addTab(self.scrollArea, self.iconFav, '')
+      self.tabW.addTab(self.scrollAreaU, self.iconSim, '')
+      self.tabW.setIconSize( QtCore.QSize(48, 48) )
+      self.tabW.setStyleSheet(' \
+         QTabBar::tab { \
+              background: #194F97; \
+/*              border: 1px solid #194F97; */\
+              } \
+            \
+          QTabBar::tab:selected, QTabBar::tab:hover { \
+              background: #2684DB; \
+/*              background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0, stop: 0 #194F97, stop: 1.0 #2684DB);*/ \
+          } ')
+      
+      self.setCentralWidget(self.tabW)
+#      self.setCentralWidget(self.scrollArea)
 
       self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
       self.connect(QtGui.QApplication.desktop(), QtCore.SIGNAL('resized(int)'), self.Resized)
 
+   def CreateScrollWidget(self, layout):
+      scrollArea = QtGui.QScrollArea(self)
+      scrollArea.setWidgetResizable(True)
+      scrollAreaWidgetContents = QtGui.QWidget(scrollArea)
+      scrollAreaWidgetContents.setObjectName('scroll')
+      scrollAreaWidgetContents.setLayout( layout )
+      scrollAreaWidgetContents.setStyleSheet("QWidget#scroll { background: #fff; margin: 0; padding: 0;} ")
+      scrollArea.setWidget(scrollAreaWidgetContents)
+      return scrollArea
+
    def Resized(self, val):
       desktop = QtGui.QApplication.desktop()
 
-#      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
-#         self.tabW.setTabPosition(QtGui.QTabWidget.East)
-#      else:
-#         self.tabW.setTabPosition(QtGui.QTabWidget.South)
+      angle=0
+      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
+         self.tabW.setTabPosition(QtGui.QTabWidget.East)
+         angle=-90
+      else:
+         self.tabW.setTabPosition(QtGui.QTabWidget.South)
+         angle=90
+
+      rotate = QtGui.QTransform().rotate(angle)
+      for tab in range(0, self.tabW.count()):
+         icon = self.tabW.tabIcon(tab)
+         pix = icon.pixmap(QtCore.QSize(48,48))
+         pix = pix.transformed( rotate )
+         icon = QtGui.QIcon(pix)
+         self.tabW.setTabIcon(tab, icon)
 
    def Refresh(self):
       DebugLog("TrainTrainView::Refresh")
       self.updateCpt=0
       self.SetLoading(True)
-      
+
       for view in self.views.values():
          view.Busy()
       self.model.RefreshDatas()
